package com.bwie.service.impl;

import com.alibaba.fastjson.JSON;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.domain.Admin;
import com.bwie.common.domain.User;
import com.bwie.common.domain.request.UserRequest;
import com.bwie.common.domain.response.JwtResponse;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.feign.UserFeign;
import com.bwie.service.AuthService;
import javafx.scene.control.Alert;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.Objects;
import java.util.UUID;
import java.util.concurrent.TimeUnit;

/**
 * @version: java version 1.8
 * @author: liguangyao
 * @date: 2023-12-10 上午 9:30
 */
@Service
public class AuthServiceImpl implements AuthService {
    @Autowired
    private UserFeign userFeign;

    @Autowired
    private StringRedisTemplate redisTemplate;

    @Override
    public Result<JwtResponse> userLogin(UserRequest userRequest) {
        Result<User> result = userFeign.userLogin(userRequest);
        User user = result.getData();
        if(user==null){
            return Result.error("没有该用户,请先前往注册");
        }

        HashMap<String, Object> map = new HashMap<>();
        String useKey = UUID.randomUUID().toString().replaceAll("-","");
        map.put(JwtConstants.USER_KEY,useKey);
        String token = JwtUtils.createToken(map);
        redisTemplate.opsForValue().set(JwtConstants.USER_KEY+token, JSON.toJSONString(user),15, TimeUnit.MINUTES);

        JwtResponse jwtResponse = new JwtResponse();
        jwtResponse.setToken(token);
        jwtResponse.setTokenMIN("15MIN");
        return Result.success(jwtResponse);
    }

    @Override
    public Result<JwtResponse> adminLogin(UserRequest userRequest) {
        Result<Admin> result = userFeign.adminLogin(userRequest);
        Admin admin = result.getData();
        if(admin==null){
            return Result.error("没有该用户,请先前往注册");
        }
        HashMap<String, Object> map = new HashMap<>();
        String useKey = UUID.randomUUID().toString().replaceAll("-","");
        map.put(JwtConstants.USER_KEY,useKey);
        String token = JwtUtils.createToken(map);
        redisTemplate.opsForValue().set(JwtConstants.USER_KEY+token, JSON.toJSONString(admin),15, TimeUnit.MINUTES);

        JwtResponse jwtResponse = new JwtResponse();
        jwtResponse.setToken(token);
        jwtResponse.setTokenMIN("15MIN");
        return Result.success(jwtResponse);
    }
}
