package com.bwie.gateway.filters;

import cn.hutool.db.Page;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import com.bwie.gateway.config.IgnoreWhiteConfig;
import com.bwie.gateway.utils.GatewayUtils;
import io.jsonwebtoken.Claims;
import io.jsonwebtoken.Jwt;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.gateway.filter.GatewayFilterChain;
import org.springframework.cloud.gateway.filter.GlobalFilter;
import org.springframework.core.Ordered;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.http.server.reactive.ServerHttpRequest;
import org.springframework.stereotype.Component;
import org.springframework.web.server.ServerWebExchange;
import reactor.core.publisher.Mono;

import java.util.List;
import java.util.concurrent.TimeUnit;

/**
 * @version: java version 1.8
 * @author: liguangyao
 * @date: 2023-12-10 上午 10:29
 */
@Component
@Log4j2
public class GatewayFilers implements GlobalFilter, Ordered {
    @Autowired
    private IgnoreWhiteConfig ignoreWhiteConfig;
    @Autowired
    private StringRedisTemplate redisTemplate;
    @Override
    public Mono<Void> filter(ServerWebExchange exchange, GatewayFilterChain chain) {

        //获取白名单
        List<String> whites = ignoreWhiteConfig.getWhites();
        //获取操作路径
        ServerHttpRequest request = exchange.getRequest();
        String path = request.getURI().getPath();
        log.info("用户操作的路径是{}",path);
        //对路径进行匹配
        if(StringUtils.matches(path,whites)){
            //通过就放行
            return chain.filter(exchange);
        }
        //获取token
        String token = request.getHeaders().getFirst("token");
        if(token==null) {
            return GatewayUtils.errorResponse(exchange,"token必须携带");
        }
        //判断token的合法性
        try {
            Claims claims = JwtUtils.parseToken(token);
        } catch (Exception e) {
            //不合法
            return GatewayUtils.errorResponse(exchange,"token不合法");
        }
        //判断token的时效性
        Long expire = redisTemplate.getExpire(JwtConstants.USER_KEY + token);
        //存入的token是15分钟也就是900秒在token剩余10分钟的时候在进行续期
        if (expire<=600L){
            //小于10分钟进行续期操作
            log.info("token进行续期续期15分钟");
            redisTemplate.expire(JwtConstants.USER_KEY+token,15, TimeUnit.MINUTES);
        }
        log.info("token通过");
        return chain.filter(exchange);
    }

    @Override
    public int getOrder() {
        return 0;
    }
}
