package com.bwie.controller;


import com.bwie.common.domain.Education;
import com.bwie.common.domain.History;
import com.bwie.common.domain.Patient;
import com.bwie.common.domain.Pressure;
import com.bwie.common.domain.Records;
import com.bwie.common.domain.Sugar;
import com.bwie.common.domain.request.HistoryRequest;
import com.bwie.common.domain.request.UserLevel;
import com.bwie.common.result.PageResult;
import com.bwie.common.result.Result;
import com.bwie.service.ListsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @version: java version 1.8
 * @author: liguangyao
 * @date: 2023-12-10 上午 9:35
 */
@RestController
public class ListsController {
    @Autowired
    private ListsService listsService;

    /**
     * 功能描述
     * 健康列表
     * @author liguangyao
     * @Date 2023/12/10
     * @param
     * @return
     */
    @GetMapping("/educationList")
    public Result<List<Education>> educationList(){
        Result<List<Education>> result = listsService.educationList();
        return result;
    }
    @PostMapping("/educationAdd")
    public Result educationAdd(@RequestBody Education education){
        Result result = listsService.educationAdd(education);
        return result;
    }
    @PostMapping("/educationDel")
    public Result educationDel(@RequestParam("contentId")String contentId){
        Result result = listsService.educationDel(contentId);
        return result;
    }
    @PostMapping("/educationUpd")
    public Result educationUpd(@RequestBody Education education){
        Result result = listsService.educationUpd(education);
        return result;
    }

    //以下的功能是根据登录人进行查看各自只能看各自的管理员登录查看所有并且可以操作
    /**
     * 功能描述
     * 过往病史列表History
     * @author liguangyao
     * @Date 2023/12/10
     * @param historyRequest
     * @return
     */
    @PostMapping("/historyList")
    public Result<PageResult<History>> historyList(@RequestBody HistoryRequest historyRequest){
        Result<PageResult<History>> result = listsService.historyList(historyRequest);
        return result;
    }
    @PostMapping("/historyAdd")
    public Result historyAdd(@RequestBody History history){
        Result result = listsService.historyAdd(history);
        return result;
    }
    @PostMapping("/historyUpd")
    public Result historyUpd(@RequestBody History history){
        Result result = listsService.historyUpd(history);
        return result;
    }
    @PostMapping("/historyDel")
    public Result historyDel(@RequestParam("historyId") String historyId){
        Result result = listsService.historyDel(historyId);
        return result;
    }
    /**
     * 功能描述
     * 糖尿病管理列表Patient只能管理员进行查看
     * @author liguangyao
     * @Date 2023/12/10
     * @param
     * @return
     */
    @PostMapping("/patientList")
    public Result<PageResult<Patient>> patientList(@RequestBody UserLevel userLevel){
        Result<PageResult<Patient>> result = listsService.patientList(userLevel);
        return result;
    }
    @PostMapping("/patientDel")
    public Result patientDel(@RequestParam("patientId") String patientId){
        Result result = listsService.patientDel(patientId);
        return result;
    }
    @PostMapping("/patientAdd")
    public Result patientAdd(@RequestBody Patient patient){
        Result result = listsService.patientAdd(patient);
        return result;
    }
    @PostMapping("/patientUpd")
    public Result patientUpd(@RequestBody Patient patient){
        Result result = listsService.patientUpd(patient);
        return result;
    }
    /**
     * 功能描述
     * 血压数据列表Pressure
     * @author liguangyao
     * @Date 2023/12/10
     * @param userLevel
     * @return
     */
    @PostMapping("/pressureList")
    public Result<PageResult<Pressure>> pressureList(@RequestBody UserLevel userLevel){
        Result<PageResult<Pressure>> result = listsService.pressureList(userLevel);
        return result;
    }

    @PostMapping("/pressureDel")
    public Result pressureDel(@RequestParam("pressureId") String pressureId){
        Result result = listsService.pressureDel(pressureId);
        return result;
    }
    @PostMapping("/pressureAdd")
    public Result pressureAdd(@RequestBody Pressure pressure){
        Result result = listsService.pressureAdd(pressure);
        return result;
    }
    @PostMapping("/pressureUpd")
    public Result pressureUpd(@RequestBody Pressure pressure){
        Result result = listsService.pressureUpd(pressure);
        return result;
    }
    /**
     * 功能描述
     * 健康档案表Records
     * @author liguangyao
     * @Date 2023/12/10
     * @param userLevel
     * @return
     */
    @PostMapping("/recordsList")
    public Result<PageResult<Records>> recordsList(@RequestBody UserLevel userLevel){
        Result<PageResult<Records>> result = listsService.recordsList(userLevel);
        return result;
    }

    @PostMapping("/recordsDel")
    public Result recordsDel(@RequestParam("records") String recordsId){
        Result result = listsService.recordsDel(recordsId);
        return result;
    }
    @PostMapping("/recordsAdd")
    public Result recordsAdd(@RequestBody Records records){
        Result result = listsService.recordsAdd(records);
        return result;
    }
    @PostMapping("/recordsUpd")
    public Result recordsUpd(@RequestBody Records records){
        Result result = listsService.recordsUpd(records);
        return result;
    }
    /**
     * 功能描述
     * 血糖表Sugar
     * @author liguangyao
     * @Date 2023/12/10
     * @param userLevel
     * @return
     */
    @PostMapping("/sugarList")
    public Result<PageResult<Sugar>> sugarList(@RequestBody UserLevel userLevel){
        Result<PageResult<Sugar>> result = listsService.sugarList(userLevel);
        return result;
    }

    @PostMapping("/sugarDel")
    public Result sugarDel(@RequestParam("sugarId") Sugar sugarId){
        Result result = listsService.sugarDel(sugarId);
        return result;
    }
    @PostMapping("/sugarAdd")
    public Result sugarAdd(@RequestBody Sugar sugar){
        Result result = listsService.sugarAdd(sugar);
        return result;
    }
    @PostMapping("/sugarUpd")
    public Result sugarUpd(@RequestBody Sugar sugar){
        Result result = listsService.sugarUpd(sugar);
        return result;
    }



}
